using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Windows.Documents;

namespace HeatmapBindingTest
{
    public class MainWindowViewModel : INotifyPropertyChanged
    {
        

        public MainWindowViewModel()
        {

            SizeColumns = new List<string>() { "PositionSize", "Exposure",  };
            SelectedSizeColumn = SizeColumns.FirstOrDefault();
            ColorColumns = new List<string>() { "DtdPnl","MtdPnl","YtdPnl" };
            SelectedColorColumn = ColorColumns.FirstOrDefault();


            ReportItems = new ObservableCollection<ReportDataItem>();

            Random random = new Random(DateTime.Now.Millisecond);
            int MaxBand1 = 5;
            int MaxBand2 = 5;

            for (int band1 = 1; band1 < MaxBand1; band1++)
            {
                var band1Item = new ReportDataItem()
                {
                    GroupType = "Band1",
                    GroupName = string.Format("Band1.{0}", band1),
                    PositionSize = (decimal)random.NextDouble() * 1000 * 1000,
                    Exposure = (decimal)random.NextDouble() * 1000 * 1000 * 1000,
                    DtdPnl = band1 > 2 ? -10m * (decimal)random.NextDouble() : 10m * (decimal)random.NextDouble(),
                    MtdPnl = band1 > 2 ? -10m * (decimal)random.NextDouble() : 10m * (decimal)random.NextDouble(),
                    YtdPnl = band1 > 2 ? -10m * (decimal)random.NextDouble() : 10m * (decimal)random.NextDouble()
                };



                ReportItems.Add(band1Item);

                for (int band2 = 1; band2 < MaxBand2; band2++)
                {
                    var band2Item = new ReportDataItem()
                    {
                        GroupType = "Band2",
                        GroupName = string.Format("{0}.{1}", band1Item.GroupName, band2),
                        PositionSize = band1Item.PositionSize / (decimal)MaxBand2 * (decimal)band2,
                        Exposure = band1Item.Exposure / (decimal)MaxBand2 * (decimal)band2,
                        DtdPnl = band1Item.DtdPnl / (decimal)MaxBand2 * (decimal)band2,
                        MtdPnl = band1Item.MtdPnl / (decimal)MaxBand2 * (decimal)band2,
                        YtdPnl = band1Item.YtdPnl / (decimal)MaxBand2 * (decimal)band2,
                    };
                    band1Item.Children.Add(band2Item);
                }

            }
        }


        public ObservableCollection<ReportDataItem> ReportItems { get; set; }


        public List<string> SizeColumns { get; set; }

        private string _selectedSizeColumn;
        public string SelectedSizeColumn
        {
            get { return _selectedSizeColumn; }
            set
            {
                _selectedSizeColumn = value;
                OnPropertyChanged();
            }
        }

        public List<string> ColorColumns { get; set; }
        private string _selectedColorColumn;
        public string SelectedColorColumn
        {
            get { return _selectedColorColumn; }
            set
            {
                _selectedColorColumn = value;
                OnPropertyChanged();
            }
        }


        public event PropertyChangedEventHandler PropertyChanged;

        protected virtual void OnPropertyChanged([CallerMemberName] string propertyName = null)
        {
            PropertyChangedEventHandler handler = PropertyChanged;
            if (handler != null) handler(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}